#### Clustering Analysis ####
Demultiplexing of the input Fastq files was done using the _CellRanger_ v7.2.0 software (10X Genomics), followed by the aliment of the resulting input reads against the _mm10_ mouse reference genome (Ensembl 93), and the UMI quantification to produce a cell-by-gene count table for each sample.</br>
These input matrices were then imported into the _R_ environment (v. 4.3.2) and analysed with _Seurat_ v5.0.1. Cells expressing less than 500 (which suggest false identified cells or low viability) or more than 6000 (which is an indicator of potential doublets) genes were filtered out. Cells having more than 10% of transcripts coming from mitochondrial genes, corresponding to dying cells, were also removed. After these initial steps, samples were combined into a single Seurat object keeping track of their original sample and group condition (i.e., Empty, IFN, oIL2, and IFN+oIL2).</br>
The resulting merged matrix was log-normalized with a scale factor of 1000 by using the _NormalizedData_ function of the Seurat package, and the most variable genes were identified with the “vst” selection method of the _FindVariableFeatures_ function. The _ScaleData_ function was used to scale the data based on the percentage of mitochondrial genes, the absolute count of RNAs in each cell, and the difference between S and G2/M cell cycle scores computed for each cell and, after that, 50 principal components (PCs) were computed for dimensionality reduction. To remove possible batch effects among conditions, the _Harmony_ method was applied to the data considering the sample identity as variable (batch) to remove, and a UMAP-representation as well as clusters were computed on those reductions. Marker genes for each cluster were obtained using the _FindAllMarkers_ function, and consequently clusters were annotated and manually curated.</br>
Subsets of cells belonging to T cells, TAMs and DCs were identified relying on the computed cluster markers, isolated, and re-analysed following the same procedure adopted for the merged dataset.

#### Files ####

- Paper_figures.R: script to generate the plot of the clusters in the Paper_figures

- Full_T_Myelo_metadata.xlsx: file containing the meta-data of the Seurat objects used to produce the plots

![Fig5A](./Fig5A.png)
